c$Id: umati1.f,v 1.1 2004/01/11 19:11:33 rlt Exp $
      subroutine umati02(type,vv, d, ud, n1,n3)

c      * * F E A P * * A Finite Element Analysis Program

c....  Copyright (c) 1984-2004: Regents of the University of California
c                               All rights reserved

c-----[--.----+----.----+----.-----------------------------------------]
c      Purpose: Dummy user material model routine

c      Inputs:
c         type   - Name of material model
c         vv(5)  - Command line real data
c         d(*)   - Program material parameter data

c      Outputs:
c         ud(*)  - Material parameter data for model
c         n1     - Number of history items/point (time   dependent)
c         n3     - Number of history items/point (time independent)
c-----[--.----+----.----+----.-----------------------------------------]
      implicit  none

      include 'iofile.h'
      logical   pcomp, pinput, errck
      character type*15
      integer   n1,n3, ii
      real*8    vv(5),d(*),ud(*)

c     Set command name
      if(pcomp(type,'mat02',4)) then ! Default form: DO NOT CHANGE
         type = 'EMECvmdmuae2'         ! Specify new 'name'
c     Input user data and save in ud(*) array
      else          ! Perform input for user data
         n1 = 6     ! time dependent history variable    (1-Electrophysiology 2-Calcium con. 3- Active stretch 4-5-6-Passive response) 
         n3 = 11    ! time in-dependent history variable (fiber-sheet-normal directions - exciation time - segment number)
         errck = pinput(ud(1) ,9)
         errck = pinput(ud(10),6)
         errck = pinput(ud(16),9)
         errck = pinput(ud(25),9)
         write(  *,2000) 
         write(iow,2000) 
         write(  *,2001) (ud(ii), ii=1,2) 
        
      endif
 2000 format(
     * 10x,'MATERIAL MODEL FOR FEAP ------------- (c) S. Goktepe, METU'/
     * 10x,'[  ] [     ] Phenom. Electromech. Monodomain AP Model.....'/
     * 10x,'[  ] [     ] (c) Baris Cansiz ............................'/
     * 10x,'[  ] [     ] UMAT02.......................................'/
     * 10x,'[  ] [     ] Viscoelastic Q1 monodomain model.............'/
     * 10x,'[  ] [     ] Multiplicative decomp..............24/12/2013'/
     * 10x,'[  ] [     ] New active stretch formulation.....19/07/2014'/
     * 10x,'[  ] [     ] Reformulation of multip. decomp....26/08/2014'/
     * )
 2001 format(
     * 10x,'[ 1] [kappa]  p elas.: Bulk modulus (Penalty) ......',e12.5/
     * 10x,'[ 2] [    a]  p elas.: Isotropic shear modulus .....',e12.5/
     * )
 
c
      return 
      end

c$Id: umatl1.f,v 1.2 2004/02/25 21:56:20 rlt Exp $
      subroutine umatl02(f,detf,d,ud,nh,ii,istrt,sig,dd,isw)

c      * * F E A P * * A Finite Element Analysis Program

c....  Copyright (c) 1984-2004: Regents of the University of California
c                               All rights reserved

c-----[--.----+----.----+----.-----------------------------------------]
c     Purpose: User Constitutive Model 1

c     Input:
c          f(*)      -  Current strains at point      (small deformation)
c                    -  Deformation gradient at point (finite deformation)
c          detf      -  Trace of strain at point
c                    -  Determinant of deformation gradient
c          phi       -  Action potential
c          d(*)      -  Program material parameters (ndd)
c          ud(*)     -  User material parameters (nud)
c          nh        -  Number of history terms
c          ii        -  Current point number
c          l         -  Current Gauss Point number
c          isw       -  Solution option from element
c          sig(1--3) -  Volumetric Kirchhoff stresses coming from the element routine

c     Output:
c          sig(*)    -  Stresses at point.
c                       N.B. 1-d models use only sig(1)
c          dd(6,*)   -  Current material tangent moduli
c                       N.B. 1-d models use only dd(1,1) and dd(2,1)
c-----[--.----+----.----+----.-----------------------------------------]
      implicit none

      include 'tdata.h'
      include 'counts.h'
      include 'pointer.h'
      include 'cdata.h'
      include 'comblk.h'
      include 'elcoor.h'        ! xref(3), xcur(3)
      include 'eldata.h'        ! dm,n,ma,mct,mct,iel,nel
c..
      integer nh,istrt, isw, ii
      real*8  f(3,*),detf,d(*),ud(*),sig(*),dd(6,6,*)
      integer i,j,l,k,iin(6),jin(6),ij(3,3)
      real*8  xi(6), xii(6,6), aa(6,6), bb(6)
      real*8  xmm(6)
      real*8  ll1,mu1,cc(6)
      
c...  define Voigt maps 
      data iin/1,2,3,1,2,1/, jin/1,2,3,2,3,3/
      data ij/ 1 , 4 , 6 ,
     *         4 , 2 , 5 ,
     *         6 , 5 , 3 /
c...  define identity tensors 
      data  xi/1.d0,1.d0,1.d0,0.d0,0.d0,0.d0/
      data xii/1.d0, 0.d0, 0.d0, 0.d0, 0.d0, 0.d0,
     &         0.d0, 1.d0, 0.d0, 0.d0, 0.d0, 0.d0,
     &         0.d0, 0.d0, 1.d0, 0.d0, 0.d0, 0.d0,
     &         0.d0, 0.d0, 0.d0, 5.d-1,0.d0, 0.d0,
     &         0.d0, 0.d0, 0.d0, 0.d0, 5.d-1,0.d0,
     &         0.d0, 0.d0, 0.d0, 0.d0, 0.d0, 5.d-1/
c...  Vector to use in matrix summations when Voigt notation is used
      data xmm / 1.d0 , 1.d0 , 1.d0 , 2.d0 , 2.d0 , 2.d0 /

      ll1 = ud(1)               !              ll1 = 0.577d0
      mu1 = ud(2)               !              mu1 = 0.385d0
      
      bb(1) = f(1,1)*f(1,1) + f(1,2)*f(1,2) + f(1,3)*f(1,3)
      bb(2) = f(2,1)*f(2,1) + f(2,2)*f(2,2) + f(2,3)*f(2,3)
      bb(3) = f(3,1)*f(3,1) + f(3,2)*f(3,2) + f(3,3)*f(3,3)
      bb(4) = f(1,1)*f(2,1) + f(1,2)*f(2,2) + f(1,3)*f(2,3)
      bb(5) = f(2,1)*f(3,1) + f(2,2)*f(3,2) + f(2,3)*f(3,3)
      bb(6) = f(1,1)*f(3,1) + f(1,2)*f(3,2) + f(1,3)*f(3,3)

  
      
      do i = 1,6
      do j = 1,6
            aa(i,j) = 0.d0
         enddo
         sig(i) = 0.d0
      enddo
   

      do i = 1, 6
         sig(i) = (0.5d0*ll1*dlog(detf*detf) - mu1) * xi(i) + mu1*bb(i)
         sig(i) = sig(i)/detf
      enddo

      do i=1,6
      do j=1,6
      aa(i,j)
     &=ll1*xi(i)*xi(j)-(ll1*dlog(detf*detf)-2.d0*mu1)*xii(i,j)
      dd(i,j,1)=aa(i,j)/detf
      enddo
      enddo

      
 102  continue
      end
